@@ -22,7 +22,7 @@ sub _ep_edittable_edit {
     my($query, $id);
 
     my $dest = ($attr->{'dest'} ||= $table);
-    $attr->{'prefix'} ||= "$dest_";
+    $attr->{'prefix'} ||= "$dest\_";
     $attr->{'sqlquery'} ||= 1;
 
     if ($action eq 'insert') {
@@ -118,11 +118,11 @@ sub _ep_edittable_select {
 	    } elsif ($type eq '_like') {
 		push(@where, "$col LIKE " . $dbh->quote("%$val")) if $val;
 	    }
-	    push(@url, "$key=" . URI::Escape::uri_escape($val));
+	    push(@url, "$key=" . CGI->escape($val));
 	} elsif ($key =~ /^order_(\w+)_(.*)/) {
 	    push(@order, "$2 $1");
 	    my $val = $cgi->param($2);
-	    push(@url, "$key=" . URI::Escape::uri_escape($val));
+	    push(@url, "$key=" . CGI->escape($val));
 	}
     }
 
